@@ -1,8 +1,11 @@
 from classicML.api.models import BaseModel
+from classicML.api.models import AdaBoostClassifier
 from classicML.api.models import AveragedOneDependentEstimator
 from classicML.api.models import AODE
 from classicML.api.models import BackPropagationNeuralNetwork
 from classicML.api.models import BPNN
+from classicML.api.models import BaggingClassifier
+from classicML.api.models import DecisionStumpClassifier
 from classicML.api.models import DecisionTreeClassifier
 from classicML.api.models import LinearDiscriminantAnalysis
 from classicML.api.models import LDA
@@ -15,3 +18,4 @@ from classicML.api.models import SuperParentOneDependentEstimator
 from classicML.api.models import SPODE
 from classicML.api.models import SupportVectorClassifier
 from classicML.api.models import SVC
+from classicML.api.models import TwoLevelDecisionTreeClassifier
