@@ -1,3 +1,6 @@
+"""所有的导入均使用真实映射."""
+from classicML.api.models.base_model import BaseModel
+
 from classicML.api.models.bayes.naive_bayes_classifier import NaiveBayesClassifier
 from classicML.api.models.bayes.naive_bayes_classifier import NaiveBayesClassifier as NB
 from classicML.api.models.bayes.semi_naive_bayes_classifiers import AveragedOneDependentEstimator
@@ -5,6 +8,11 @@ from classicML.api.models.bayes.semi_naive_bayes_classifiers import AveragedOneD
 from classicML.api.models.bayes.semi_naive_bayes_classifiers import SuperParentOneDependentEstimator
 from classicML.api.models.bayes.semi_naive_bayes_classifiers import SuperParentOneDependentEstimator as SPODE
 
+from classicML.api.models.tree.decision_tree_classifier import DecisionStumpClassifier
+from classicML.api.models.tree.decision_tree_classifier import TwoLevelDecisionTreeClassifier
+from classicML.api.models.ensemble.bagging import BaggingClassifier
+from classicML.api.models.ensemble.boosting import AdaBoostClassifier
+
 from classicML.api.models.linear_model.linear_discriminant_analysis import LinearDiscriminantAnalysis
 from classicML.api.models.linear_model.linear_discriminant_analysis import LinearDiscriminantAnalysis as LDA
 from classicML.api.models.linear_model.logistic_regression import LogisticRegression
