@@ -3,7 +3,9 @@ from pickle import loads, dumps
 import numpy as np
 import pandas as pd
 
+from classicML import _cml_precision
 from classicML import CLASSICML_LOGGER
+from classicML.api.models import BaseModel
 from classicML.backend import get_conditional_probability
 from classicML.backend import get_dependent_prior_probability
 from classicML.backend import get_probability_density
@@ -11,7 +13,7 @@ from classicML.backend import type_of_target
 from classicML.backend import io
 
 
-class OneDependentEstimator(object):
+class OneDependentEstimator(BaseModel):
     """独依赖估计器的基类.
 
     Attributes:
@@ -43,7 +45,7 @@ class OneDependentEstimator(object):
         """
         raise NotImplementedError
 
-    def fit(self, x, y):
+    def fit(self, x, y, **kwargs):
         """训练独依赖估计器.
 
         Arguments:
@@ -52,7 +54,7 @@ class OneDependentEstimator(object):
         """
         raise NotImplementedError
 
-    def predict(self, x):
+    def predict(self, x, **kwargs):
         """使用独依赖估计器进行预测.
 
         Arguments:
@@ -131,7 +133,7 @@ class SuperParentOneDependentEstimator(OneDependentEstimator):
         self.super_parent_name = super_parent_name
         self.smoothing = smoothing
 
-    def fit(self, x, y):
+    def fit(self, x, y, **kwargs):
         """训练超父独依赖估计器.
 
         Arguments:
@@ -167,7 +169,7 @@ class SuperParentOneDependentEstimator(OneDependentEstimator):
                                                          len(x.values),
                                                          len(unique_values_xi),
                                                          self.smoothing)
-                p_c.update({'p_c_xi': p_c_xi})
+                p_c.update({'p_c_xi': _cml_precision.float(p_c_xi)})
 
                 # 获取有依赖的类条件概率P(xj|c, xi)或概率密度p(xj|c, xi)所需的信息.
                 for attribute in range(x.shape[1]):
@@ -198,12 +200,17 @@ class SuperParentOneDependentEstimator(OneDependentEstimator):
                         # 统计不同属性值的样本总数.
                         D_c_xi = dict()
                         for name in value_count:
-                            D_c_xi.update({name: float(value_count[name].values)})
+                            D_c_xi.update({name: _cml_precision.float(value_count[name].values)})
 
                         p_c.update({x.columns[attribute]: {
-                                    'continuous': continuous,
-                                    'values': [D_c_xi, c_xi.shape[0], num_of_unique_value],
-                                    'smoothing': self.smoothing}})
+                            'continuous': continuous,
+                            'values': [
+                                D_c_xi,
+                                # 指明数据类型, pure int在32位精度下会占用更多的内存.
+                                _cml_precision.int(c_xi.shape[0]),
+                                _cml_precision.int(num_of_unique_value)
+                            ],
+                            'smoothing': self.smoothing}})
 
                 self._list_of_p_c.append({'category': category, 'attribute': value, 'p_c': p_c})
 
@@ -242,9 +249,9 @@ class SuperParentOneDependentEstimator(OneDependentEstimator):
                 y_pred.append([p_0 / (p_0 + p_1), p_1 / (p_0 + p_1)])
             else:
                 if p_0 > p_1:
-                    y_pred.append(0)
+                    y_pred.append(_cml_precision.int(0))
                 else:
-                    y_pred.append(1)
+                    y_pred.append(_cml_precision.int(1))
         else:
             for i in range(x.shape[0]):
                 x_test = x.iloc[i, :]
@@ -253,11 +260,23 @@ class SuperParentOneDependentEstimator(OneDependentEstimator):
                     y_pred.append([p_0 / (p_0 + p_1), p_1 / (p_0 + p_1)])
                 else:
                     if p_0 > p_1:
-                        y_pred.append(0)
+                        y_pred.append(_cml_precision.int(0))
                     else:
-                        y_pred.append(1)
+                        y_pred.append(_cml_precision.int(1))
 
-        return y_pred
+        return np.asarray(y_pred)
+
+    def score(self, x, y):
+        """在预测模式下计算准确率.
+
+        Arguments:
+            x: array-like, 特征数据.
+            y: array-like, 标签.
+
+        Returns:
+            当前的准确率.
+        """
+        return super(SuperParentOneDependentEstimator, self).score(x, y)
 
     def load_weights(self, filepath):
         """加载模型参数.
@@ -332,7 +351,7 @@ class SuperParentOneDependentEstimator(OneDependentEstimator):
         Returns:
             返回预测的结果.
         """
-        y_pred = [0.0, 0.0]
+        y_pred = np.zeros([2], dtype=_cml_precision.float)
 
         if attribute_list is None and super_parent_index is None:
             for i in self._list_of_p_c:
@@ -372,7 +391,7 @@ class SuperParentOneDependentEstimator(OneDependentEstimator):
                         y_pred[0] += np.log(probability_density)  # 存放数据中多存放一个p_c_xi导致和x的索引无法对齐.
                     else:
                         D_c_xi_xj, D_c_xi, num_of_unique_value = _p_c[probability]['values']
-                        y_pred[0] += np.log(get_conditional_probability(D_c_xi_xj[x[index - 1]],
+                        y_pred[0] += np.log(get_conditional_probability(_cml_precision.int(D_c_xi_xj[x[index - 1]]),
                                                                         D_c_xi,
                                                                         num_of_unique_value,
                                                                         _p_c[probability]['smoothing']))
@@ -388,7 +407,7 @@ class SuperParentOneDependentEstimator(OneDependentEstimator):
                         y_pred[1] += np.log(probability_density)
                     else:
                         D_c_xi_xj, D_c_xi, num_of_unique_value = _p_c[probability]['values']
-                        y_pred[1] += np.log(get_conditional_probability(D_c_xi_xj[x[index - 1]],
+                        y_pred[1] += np.log(get_conditional_probability(_cml_precision.int(D_c_xi_xj[x[index - 1]]),
                                                                         D_c_xi,
                                                                         num_of_unique_value,
                                                                         _p_c[probability]['smoothing']))
@@ -434,7 +453,7 @@ class AveragedOneDependentEstimator(SuperParentOneDependentEstimator):
         self.smoothing = smoothing
         self.m = m
 
-    def fit(self, x, y):
+    def fit(self, x, y, **kwargs):
         """训练平均独依赖估计器.
 
         Arguments:
@@ -505,7 +524,19 @@ class AveragedOneDependentEstimator(SuperParentOneDependentEstimator):
                 x_test = x.iloc[i, :]
                 y_pred.append(self._predict(x_test))
 
-        return y_pred
+        return np.asarray(y_pred)
+
+    def score(self, x, y):
+        """在预测模式下计算准确率.
+
+        Arguments:
+            x: array-like, 特征数据.
+            y: array-like, 标签.
+
+        Returns:
+            当前的准确率.
+        """
+        return super(AveragedOneDependentEstimator, self).score(x, y)
 
     def load_weights(self, filepath):
         """加载模型参数.
@@ -576,13 +607,13 @@ class AveragedOneDependentEstimator(SuperParentOneDependentEstimator):
         Returns:
             返回预测的结果.
         """
-        avg_result = {'0': 0.0, '1': 0.0}
+        avg_result = {'0': _cml_precision.float(0.0), '1': _cml_precision.float(0.0)}
         for i in range(len(self._attribute_list)):
             _temp_y_pred = super(AveragedOneDependentEstimator, self)._predict(x, self._attribute_list, i)
             avg_result['0'] += _temp_y_pred[0]
             avg_result['1'] += _temp_y_pred[1]
 
         if avg_result['0'] > avg_result['1']:
-            return 0
+            return _cml_precision.int(0)
         else:
-            return 1
+            return _cml_precision.int(1)
